==> r2r-3.2.0.tar.gz: r2r-3.2.0/core/base/abstractions/__init__.py <==
from shared.abstractions.base import AsyncSyncMeta, R2RSerializable, syncable
from shared.abstractions.completion import CompletionRecord, MessageType
from shared.abstractions.document import (
    DataType,
    Document,
    DocumentExtraction,
    DocumentInfo,
    DocumentType,
    IngestionStatus,
    KGCreationStatus,
    KGEnrichmentStatus,
)
from shared.abstractions.embedding import (
    EmbeddingPurpose,
    default_embedding_prefixes,
)
from shared.abstractions.exception import (
    R2RDocumentProcessingError,
    R2RException,
)
from shared.abstractions.graph import (
    Community,
    CommunityReport,
    Entity,
    EntityType,
    KGExtraction,
    RelationshipType,
    Triple,
)
from shared.abstractions.kg import KGCreationSettings, KGEnrichmentSettings
from shared.abstractions.llm import (
    GenerationConfig,
    LLMChatCompletion,
    LLMChatCompletionChunk,
    Message,
    RAGCompletion,
)
from shared.abstractions.prompt import Prompt
from shared.abstractions.search import (
    AggregateSearchResult,
    HybridSearchSettings,
    KGCommunityResult,
    KGEntityResult,
    KGGlobalResult,
    KGRelationshipResult,
    KGSearchMethod,
    KGSearchResult,
    KGSearchResultType,
    KGSearchSettings,
    VectorSearchResult,
    VectorSearchSettings,
)
from shared.abstractions.user import Token, TokenData, UserStats
from shared.abstractions.vector import (
    StorageResult,
    Vector,
    VectorEntry,
    VectorType,
)

__all__ = [
    # Base abstractions
    "R2RSerializable",
    "AsyncSyncMeta",
    "syncable",
    # Completion abstractions
    "CompletionRecord",
    "MessageType",
    # Document abstractions
    "DataType",
    "Document",
    "DocumentExtraction",
    "DocumentInfo",
    "IngestionStatus",
    "KGCreationStatus",
    "KGEnrichmentStatus",
    "DocumentType",
    # Embedding abstractions
    "EmbeddingPurpose",
    "default_embedding_prefixes",
    # Exception abstractions
    "R2RDocumentProcessingError",
    "R2RException",
    # Graph abstractions
    "Entity",
    "EntityType",
    "RelationshipType",
    "Community",
    "CommunityReport",
    "KGExtraction",
    "Triple",
    # LLM abstractions
    "GenerationConfig",
    "LLMChatCompletion",
    "LLMChatCompletionChunk",
    "Message",
    "RAGCompletion",
    # Prompt abstractions
    "Prompt",
    # Search abstractions
    "AggregateSearchResult",
    "KGSearchResult",
    "KGSearchMethod",
    "KGSearchResultType",
    "KGEntityResult",
    "KGRelationshipResult",
    "KGCommunityResult",
    "KGGlobalResult",
    "KGSearchSettings",
    "VectorSearchResult",
    "VectorSearchSettings",
    "HybridSearchSettings",
    # Restructure abstractions
    "KGCreationSettings",
    "KGEnrichmentSettings",
    # User abstractions
    "Token",
    "TokenData",
    "UserStats",
    # Vector abstractions
    "Vector",
    "VectorEntry",
    "VectorType",
    "StorageResult",
]

==> r2r-3.2.2.tar.gz: r2r-3.2.2/core/base/abstractions/__init__.py <==
from shared.abstractions.base import AsyncSyncMeta, R2RSerializable, syncable
from shared.abstractions.completion import CompletionRecord, MessageType
from shared.abstractions.document import (
    DataType,
    Document,
    DocumentExtraction,
    DocumentInfo,
    DocumentType,
    IngestionStatus,
    KGExtractionStatus,
    KGEnrichmentStatus,
)
from shared.abstractions.embedding import (
    EmbeddingPurpose,
    default_embedding_prefixes,
)
from shared.abstractions.exception import (
    R2RDocumentProcessingError,
    R2RException,
)
from shared.abstractions.graph import (
    Community,
    CommunityReport,
    Entity,
    EntityType,
    KGExtraction,
    RelationshipType,
    Triple,
)
from shared.abstractions.kg import (
    KGCreationEstimationResponse,
    KGCreationSettings,
    KGEnrichmentEstimationResponse,
    KGEnrichmentSettings,
    KGRunType,
)
from shared.abstractions.llm import (
    GenerationConfig,
    LLMChatCompletion,
    LLMChatCompletionChunk,
    Message,
    RAGCompletion,
)
from shared.abstractions.prompt import Prompt
from shared.abstractions.search import (
    AggregateSearchResult,
    HybridSearchSettings,
    KGCommunityResult,
    KGEntityResult,
    KGGlobalResult,
    KGRelationshipResult,
    KGSearchMethod,
    KGSearchResult,
    KGSearchResultType,
    KGSearchSettings,
    VectorSearchResult,
    VectorSearchSettings,
)
from shared.abstractions.user import Token, TokenData, UserStats
from shared.abstractions.vector import (
    StorageResult,
    Vector,
    VectorEntry,
    VectorType,
)

__all__ = [
    # Base abstractions
    "R2RSerializable",
    "AsyncSyncMeta",
    "syncable",
    # Completion abstractions
    "CompletionRecord",
    "MessageType",
    # Document abstractions
    "DataType",
    "Document",
    "DocumentExtraction",
    "DocumentInfo",
    "IngestionStatus",
    "KGExtractionStatus",
    "KGEnrichmentStatus",
    "DocumentType",
    # Embedding abstractions
    "EmbeddingPurpose",
    "default_embedding_prefixes",
    # Exception abstractions
    "R2RDocumentProcessingError",
    "R2RException",
    # Graph abstractions
    "Entity",
    "EntityType",
    "RelationshipType",
    "Community",
    "CommunityReport",
    "KGExtraction",
    "Triple",
    # LLM abstractions
    "GenerationConfig",
    "LLMChatCompletion",
    "LLMChatCompletionChunk",
    "Message",
    "RAGCompletion",
    # Prompt abstractions
    "Prompt",
    # Search abstractions
    "AggregateSearchResult",
    "KGSearchResult",
    "KGSearchMethod",
    "KGSearchResultType",
    "KGEntityResult",
    "KGRelationshipResult",
    "KGCommunityResult",
    "KGGlobalResult",
    "KGSearchSettings",
    "VectorSearchResult",
    "VectorSearchSettings",
    "HybridSearchSettings",
    # Restructure abstractions
    "KGCreationSettings",
    "KGEnrichmentSettings",
    "KGRunType",
    "KGCreationEstimationResponse",
    "KGEnrichmentEstimationResponse",
    # User abstractions
    "Token",
    "TokenData",
    "UserStats",
    # Vector abstractions
    "Vector",
    "VectorEntry",
    "VectorType",
    "StorageResult",
]
